@@ -1,9 +1,22 @@
 /*
+    This file is part of Photoflare.
 
-  Batch dialog class for the PhotoFlare application.
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
 */
 
+// Batch dialog class for the Photoflare application.
+
 //#include <QDebug>
 #include <QFileDialog>
 #include <QColorDialog>
@@ -545,3 +558,13 @@ void batchDialog::addItemToFileListWidget(QString filePath)
     ui->listWidget->setIconSize(QSize(64,64));
     ui->listWidget->addItem(itm);
 }
+
+void batchDialog::on_addFilterButton_clicked()
+{
+    on_listWidget_2_doubleClicked(ui->listWidget_2->currentIndex());
+}
+
+void batchDialog::on_removeFilterButton_clicked()
+{
+    on_listWidget_3_doubleClicked(ui->listWidget_3->currentIndex());
+}
