@@ -1,12 +1,23 @@
+/*
+    This file is part of Photoflare.
+
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
+*/
+
 #ifndef BATCHDIALOG_H
 #define BATCHDIALOG_H
 
-/*
-
-  Batch dialog class for the PhotoFlare application.
-
-*/
-
 #include <QDialog>
 #include <brushtypecombobox.h>
 #include "imagepositionwidget.h"
@@ -106,6 +117,10 @@ private slots:
 
     void addItemToFileListWidget(QString filePath);
 
+    void on_addFilterButton_clicked();
+
+    void on_removeFilterButton_clicked();
+
 private:
     Ui::batchDialog *ui;
     BatchDialogPrivate *d;
