@@ -1,9 +1,22 @@
 /*
+    This file is part of Photoflare.
 
-  Preferences dialog class.
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
 */
 
+// Preferences dialog class.
+
 #include <QFileDialog>
 #include <QApplication>
 #include <QProcess>
@@ -36,14 +49,21 @@ prefsDialog::prefsDialog(QWidget *parent) :
     ui->compressionSlider->setValue(SETTINGS->getCompressionDefaultValue().toInt());
 
     //Layout tab
-    QStringList toolList(QStringList() << "Right" << "Left");
+    QStringList toolList(QStringList() << tr("Right") << tr("Left"));
     ui->toolPaletteLocation->addItems(toolList);
 
-    if(SETTINGS->getDockLayout() == "Left")
+    if(SETTINGS->getDockLayout() == "1")
     {
         ui->toolPaletteLocation->setCurrentIndex(1);
     }
 
+    QStringList zoomList(QStringList() << tr("Default") << tr("Inverted"));
+    ui->zoomDirection->addItems(zoomList);
+    if(SETTINGS->getZoomDirection() == "1")
+    {
+        ui->zoomDirection->setCurrentIndex(1);
+    }
+
     //Default values tab
     ui->memorizeParams->setChecked(SETTINGS->getMemParamsEnabled());
     ui->unitsCBox->setCurrentIndex(SETTINGS->getUnit());
@@ -66,14 +86,15 @@ prefsDialog::prefsDialog(QWidget *parent) :
     ui->historySlider->setValue(SETTINGS->getHistoryLimit().toInt());
 
     //Startup tab
-    QStringList list(QStringList() << "English" << "French" << "Dutch" << "German" << "Chinese" << "Czech Republic");
+    QStringList list(QStringList() << "English" << "French" << "Dutch" << "German" << "Chinese (CN)" << "Chinese (TW)" << "Czech Republic");
     ui->comboBoxLanguage->addItems(list);
     ui->comboBoxLanguage->setItemIcon(0,QIcon(flagPath+"United-kingdom.png"));
     ui->comboBoxLanguage->setItemIcon(1,QIcon(flagPath+"France.png"));
     ui->comboBoxLanguage->setItemIcon(2,QIcon(flagPath+"Netherlands.png"));
     ui->comboBoxLanguage->setItemIcon(3,QIcon(flagPath+"Germany.png"));
-    ui->comboBoxLanguage->setItemIcon(4,QIcon(flagPath+"Taiwan.png"));
-    ui->comboBoxLanguage->setItemIcon(5,QIcon(flagPath+"Czech-Republic.png"));
+    ui->comboBoxLanguage->setItemIcon(4,QIcon(flagPath+"China.png"));
+    ui->comboBoxLanguage->setItemIcon(5,QIcon(flagPath+"Taiwan.png"));
+    ui->comboBoxLanguage->setItemIcon(6,QIcon(flagPath+"Czech-Republic.png"));
 
     ui->checkBoxMaximize->setChecked(SETTINGS->isMaximizeWindow());
     ui->checkBox->setChecked(SETTINGS->isMultiWindowMode());
@@ -86,10 +107,12 @@ prefsDialog::prefsDialog(QWidget *parent) :
         ui->comboBoxLanguage->setCurrentIndex(2);
     else if(SETTINGS->getUserLanguage() == "de")
         ui->comboBoxLanguage->setCurrentIndex(3);
-    else if(SETTINGS->getUserLanguage() == "zh_TW")
+    else if(SETTINGS->getUserLanguage() == "zh_CN")
             ui->comboBoxLanguage->setCurrentIndex(4);
-    else if(SETTINGS->getUserLanguage() == "cs")
+    else if(SETTINGS->getUserLanguage() == "zh_TW")
             ui->comboBoxLanguage->setCurrentIndex(5);
+    else if(SETTINGS->getUserLanguage() == "cs")
+            ui->comboBoxLanguage->setCurrentIndex(6);
 
     ui->restartButton->hide();
 }
@@ -109,14 +132,8 @@ void prefsDialog::on_buttonBox_accepted()
     SETTINGS->setPreviouslyOpenedSave(ui->previousOpenedSaveEnabled->isChecked());
 
     //Layout tab
-    if(ui->toolPaletteLocation->currentIndex() == 0)
-    {
-        SETTINGS->setDockLayout("Right");
-    }
-    else
-    {
-        SETTINGS->setDockLayout("Left");
-    }
+    SETTINGS->setDockLayout(QString::number(ui->toolPaletteLocation->currentIndex()));
+    SETTINGS->setZoomDirection(QString::number(ui->zoomDirection->currentIndex()));
 
     //Default values tab
     SETTINGS->setMemParamsEnabled(ui->memorizeParams->isChecked());
@@ -221,7 +238,9 @@ void prefsDialog::set_user_language()
     else if(ui->comboBoxLanguage->currentIndex() == 3)
         SETTINGS->setUserLanguage("de");
     else if(ui->comboBoxLanguage->currentIndex() == 4)
-        SETTINGS->setUserLanguage("zh_TW");
+        SETTINGS->setUserLanguage("zh_CN");
     else if(ui->comboBoxLanguage->currentIndex() == 5)
+        SETTINGS->setUserLanguage("zh_TW");
+    else if(ui->comboBoxLanguage->currentIndex() == 6)
         SETTINGS->setUserLanguage("cs");
 }
