@@ -1,9 +1,22 @@
 /*
+    This file is part of Photoflare.
 
-  PhotoFlare main program.
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
 */
 
+// Photoflare main program.
+
 //#include <QDebug>
 
 #include <QApplication>
@@ -20,7 +33,7 @@
 
 int main(int argc, char *argv[])
 {
-    QtSingleApplication app("PhotoFlare", argc, argv);
+    QtSingleApplication app("Photoflare", argc, argv);
 
     // Remove WhatIsThis from Window Controls (Windows only)
     #ifdef WIN32
@@ -30,16 +43,23 @@ int main(int argc, char *argv[])
     if(!app.isRunning())
     {
         app.setApplicationName(QObject::tr("photoflare"));
-        app.setApplicationVersion(QObject::tr("1.5.9"));
+        app.setApplicationVersion(QObject::tr("1.6.2"));
         app.setOrganizationDomain(QObject::tr("photoflare.io"));
 
         // Setup Default settings
         QString loc = QStandardPaths::locate(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory)+"photoflare.io";
-        if(QDir(loc).exists() == false)
+        if(!QDir(loc).exists())
         {
             SETTINGS->setDefaultSettings();
         }
 
+        // Setup plugins folder if needed
+        QString pluginLoc = QStandardPaths::locate(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory)+"photoflare.io/plugins";
+        if(!QDir(pluginLoc).exists())
+        {
+            QDir().mkdir(pluginLoc);
+        }
+
         // Set language based on System locale
         if(SETTINGS->getUserLanguage() == "notset")
         {
@@ -63,6 +83,10 @@ int main(int argc, char *argv[])
                 lang = "nl";
             }
             else if(sysLanguage == "Chinese")
+            {
+                lang = "zh_CN";
+            }
+            else if(sysLanguage == "Taiwan")
             {
                 lang = "zh_TW";
             }
