@@ -1,9 +1,22 @@
 ﻿/*
+    This file is part of Photoflare.
 
-  Main window class for the PhotoFlare application.
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
 */
 
+// Main window class for the Photoflare application.
+
 //#include <QDebug>
 
 #include <QClipboard>
@@ -56,7 +69,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
-#include "widgets/layermanager.h"
 #include "widgets/PaintWidget.h"
 #include "dialogs/NewDialog.h"
 #include "dialogs/aboutdialog.h"
@@ -76,6 +88,9 @@
 #include "workers/BatchProcessWorker.h"
 #include "progress/batchprogress.h"
 #include "workers/filterworker.h"
+#include "workers/filterworkermp.h"
+
+#include <omp.h>
 
 #define PAINT_BRUSH ToolManager::instance()->paintBrush()
 #define PAINT_BRUSH_ADV ToolManager::instance()->paintBrushAdv()
@@ -102,9 +117,47 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    // Add Settings Widgets to the Dock
+    addSettingsWidgets();
+
+    // Connect signals to the various Tools
+    connectTools();
+
+    // Setup additional workspace UI after parsing ui file
+    setupWorkspace();
+
+    // Disable actions that are not yet implemented. True = hidden, False = Disabled
+    disableUnimplementedActions(true);
+
+    // Create the keyboard shortcut bindings
+    createKeyboardShortcuts();
+
+    // Setup some other defaults on startup
+    setWindowSize();
+    updateRecentFilesMenu();
+}
+
+MainWindow::~MainWindow()
+{
+    delete ui;
+}
+
+/*
+
+    | Initial GUI Setup |
+
+*/
+
+void MainWindow::setupWorkspace()
+{
+    // Set icon theme - WIP
     //QString theme = "Retro";
     //applyTheme(theme);
 
+    // Add zoom ComboBox
+    addZoomCombo();
+
+    // Set window mode
     if(SETTINGS->isMultiWindowMode())
     {
         ui->mdiArea->setViewMode(QMdiArea::SubWindowView);
@@ -114,7 +167,8 @@ MainWindow::MainWindow(QWidget *parent) :
         ui->mdiArea->setViewMode(QMdiArea::TabbedView);
     }
 
-    if(SETTINGS->getDockLayout() == "Left")
+    // Set dock layout
+    if(SETTINGS->getDockLayout() == "1")
     {
         addDockWidget(Qt::LeftDockWidgetArea, ui->dockWidget_palette);
         addDockWidget(Qt::LeftDockWidgetArea, ui->dockWidgetSettings);
@@ -123,13 +177,32 @@ MainWindow::MainWindow(QWidget *parent) :
     // Center colorBox in tool palette.
     ui->verticalLayout->setAlignment(ui->colorBoxWidget, Qt::AlignCenter);
 
-    // Disable actions that are not yet implemented. True = hidden, False = Disabled
-    disableUnimplementedActions(true);
+    // Default the transparent dialog and colour mode
+    transparentDialog = 0;
+    ui->actionRGB_Mode->setChecked(true);
 
-    // Create the keyboard shortcut bindings
-    createKeyboardShortcuts();
+    // Remove Qt contextmenu from the toolbars
+    setContextMenuPolicy(Qt::NoContextMenu);
 
-    // Add zoom ComboBox
+    // Setup status text defaults
+    batchLbl = new QLabel(tr("Ready"));
+    batchLbl->setStyleSheet("margin:0 100 0 0");
+    ui->statusBar->addWidget(batchLbl);
+
+    // Disable undo/redo buttons on startup
+    ui->actionUndo->setEnabled(false);
+    ui->actionRedo->setEnabled(false);
+
+    // Set checked by default
+    ui->actionFilterbar->setChecked(true);
+    ui->actionToolpalette->setChecked(true);
+
+    // Pointer tool selected by default
+    on_toolButtonPointer_clicked();
+}
+
+void MainWindow::addZoomCombo()
+{
     zoomCombo = new QComboBox;
     zoomCombo->setFocusPolicy( Qt::NoFocus );
     // FIXME: String below should probably be localized.
@@ -142,61 +215,10 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->mainToolBar->addWidget(zoomCombo);
     connect(zoomCombo, SIGNAL(activated(const QString&)), this, SLOT(onZoomChanged(const QString&)));
     connect(ui->mdiArea, &QMdiArea::subWindowActivated, this, &MainWindow::onSubWindowActivated);
+}
 
-    // Add the LayerManager to the left dock
-    m_layerListWidget = new LayerManager;
-    //ui->dockWidgetLayers->layout()->addWidget(m_layerListWidget);
-    ui->dockWidgetLayers->hide(); //Hide layers for now
-
-    // Add Settings Widgets to the Dock
-    m_ptSettingsWidget = new PointerSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_ptSettingsWidget);
-    connect(m_ptSettingsWidget, &PointerSettingsWidget::settingsChanged, this, &MainWindow::onPointerToolSettingsChanged);
-
-    m_pbSettingsWidget = new PaintBrushSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_pbSettingsWidget);
-    connect(m_pbSettingsWidget, &PaintBrushSettingsWidget::settingsChanged, this, &MainWindow::onPaintBrushSettingsChanged);
-
-    m_pbAdvSettingsWidget = new PaintBrushAdvSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_pbAdvSettingsWidget);
-    connect(m_pbAdvSettingsWidget, &PaintBrushAdvSettingsWidget::settingsChanged, this, &MainWindow::onPaintBrushAdvSettingsChanged);
-
-    m_scSettingsWidget = new SprayCanSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_scSettingsWidget);
-    connect(m_scSettingsWidget, &SprayCanSettingsWidget::settingsChanged, this, &MainWindow::onSprayCanSettingsChanged);
-
-    m_lineSettingsWidget = new LineSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_lineSettingsWidget);
-    connect(m_lineSettingsWidget, &LineSettingsWidget::settingsChanged, this, &MainWindow::onLineSettingsChanged);
-
-    m_magicWandSettingsWidget = new MagicWandSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_magicWandSettingsWidget);
-    connect(m_magicWandSettingsWidget, &MagicWandSettingsWidget::settingsChanged, this, &MainWindow::onMagicWandSettingsChanged);
-
-    m_stampSettingsWidget = new StampSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_stampSettingsWidget);
-    connect(m_stampSettingsWidget, &StampSettingsWidget::settingsChanged, this, &MainWindow::onStampSettingsChanged);
-
-    m_blurSettingsWidget = new BlurSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_blurSettingsWidget);
-    connect(m_blurSettingsWidget, &BlurSettingsWidget::settingsChanged, this, &MainWindow::onBlurSettingsChanged);
-
-    m_eraserSettingsWidget = new EraserSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_eraserSettingsWidget);
-    connect(m_eraserSettingsWidget, &EraserSettingsWidget::settingsChanged, this, &MainWindow::onEraserSettingsChanged);
-
-    m_smudgeSettingsWidget = new SmudgeSettingsWidget;
-    ui->dockWidgetSettings->layout()->addWidget(m_smudgeSettingsWidget);
-    connect(m_smudgeSettingsWidget, &SmudgeSettingsWidget::settingsChanged, this, &MainWindow::onSmudgeSettingsChanged);
-
-    // Disable undo/redo buttons on startup
-    ui->actionUndo->setEnabled(false);
-    ui->actionRedo->setEnabled(false);
-
-    // Set checked by default
-    ui->actionFilterbar->setChecked(true);
-    ui->actionToolpalette->setChecked(true);
-
+void MainWindow::connectTools()
+{
     // Setup Tool Initial Colours and link signals to the colorChanged functions
     PAINT_BRUSH->setPrimaryColor(ui->colorBoxWidget->primaryColor());
     PAINT_BRUSH->setSecondaryColor(ui->colorBoxWidget->secondaryColor());
@@ -243,27 +265,49 @@ MainWindow::MainWindow(QWidget *parent) :
     QObject::connect(MAGIC_WAND, SIGNAL(selectPrimaryColor(const QPoint&,int,bool)), this, SLOT(onSelectPrimaryColor(const QPoint&,int,bool)));
 
     QObject::connect(SETTINGS, SIGNAL(multiWindowModeChanged(bool)), this, SLOT(onMultiWindowModeChanged(bool)));
-
-    // Setup some other defaults on startup
-    setWindowSize();
-    updateRecentFilesMenu();
-
-    transparentDialog = 0;
-    ui->actionRGB_Mode->setChecked(true);
-
-    on_toolButtonPointer_clicked();
-
-    // Remove Qt contextmenu from the toolbars
-    setContextMenuPolicy(Qt::NoContextMenu);
-
-    batchLbl = new QLabel(tr("Ready"));
-    batchLbl->setStyleSheet("margin:0 100 0 0");
-    ui->statusBar->addWidget(batchLbl);
 }
 
-MainWindow::~MainWindow()
+void MainWindow::addSettingsWidgets()
 {
-    delete ui;
+    m_ptSettingsWidget = new PointerSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_ptSettingsWidget);
+    connect(m_ptSettingsWidget, &PointerSettingsWidget::settingsChanged, this, &MainWindow::onPointerToolSettingsChanged);
+
+    m_pbSettingsWidget = new PaintBrushSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_pbSettingsWidget);
+    connect(m_pbSettingsWidget, &PaintBrushSettingsWidget::settingsChanged, this, &MainWindow::onPaintBrushSettingsChanged);
+
+    m_pbAdvSettingsWidget = new PaintBrushAdvSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_pbAdvSettingsWidget);
+    connect(m_pbAdvSettingsWidget, &PaintBrushAdvSettingsWidget::settingsChanged, this, &MainWindow::onPaintBrushAdvSettingsChanged);
+
+    m_scSettingsWidget = new SprayCanSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_scSettingsWidget);
+    connect(m_scSettingsWidget, &SprayCanSettingsWidget::settingsChanged, this, &MainWindow::onSprayCanSettingsChanged);
+
+    m_lineSettingsWidget = new LineSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_lineSettingsWidget);
+    connect(m_lineSettingsWidget, &LineSettingsWidget::settingsChanged, this, &MainWindow::onLineSettingsChanged);
+
+    m_magicWandSettingsWidget = new MagicWandSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_magicWandSettingsWidget);
+    connect(m_magicWandSettingsWidget, &MagicWandSettingsWidget::settingsChanged, this, &MainWindow::onMagicWandSettingsChanged);
+
+    m_stampSettingsWidget = new StampSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_stampSettingsWidget);
+    connect(m_stampSettingsWidget, &StampSettingsWidget::settingsChanged, this, &MainWindow::onStampSettingsChanged);
+
+    m_blurSettingsWidget = new BlurSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_blurSettingsWidget);
+    connect(m_blurSettingsWidget, &BlurSettingsWidget::settingsChanged, this, &MainWindow::onBlurSettingsChanged);
+
+    m_eraserSettingsWidget = new EraserSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_eraserSettingsWidget);
+    connect(m_eraserSettingsWidget, &EraserSettingsWidget::settingsChanged, this, &MainWindow::onEraserSettingsChanged);
+
+    m_smudgeSettingsWidget = new SmudgeSettingsWidget;
+    ui->dockWidgetSettings->layout()->addWidget(m_smudgeSettingsWidget);
+    connect(m_smudgeSettingsWidget, &SmudgeSettingsWidget::settingsChanged, this, &MainWindow::onSmudgeSettingsChanged);
 }
 
 /*
@@ -301,6 +345,26 @@ void MainWindow::applyThreadedFilter(QString filterName, double dV)
     batchLbl->setText(tr("Working..."));
 }
 
+void MainWindow::applyThreadedFilterMP(QString filterName, double dV)
+{
+    QThread *thread = new QThread();
+    FilterWorkerMP *worker = new FilterWorkerMP();
+    worker->setFilter(filterName);
+
+    PaintWidget *widget = getCurrentPaintWidget();
+    if(widget)
+    worker->setImage(widget->image());
+    worker->setDoubleVal(dV);
+    worker->setParent(this);
+    worker->moveToThread(thread);
+
+    connect(thread, SIGNAL(started()), worker, SLOT(process()));
+    connect(worker, SIGNAL(filterProcessFinished(QImage)), this, SLOT(on_image_filtered(QImage)));
+    thread->start();
+
+    batchLbl->setText(tr("Working..."));
+}
+
 /*
 
     | FILE MENU |
@@ -738,6 +802,8 @@ void MainWindow::onPaste()
         QClipboard *clipboard = QApplication::clipboard();
         widget->setPaintTool(MOUSE_POINTER);
         MOUSE_POINTER->setOverlayImage(clipboard->image());
+        m_toolSelected = "pointer";
+        refreshTools();
     }
     else
     {
@@ -1050,22 +1116,6 @@ void MainWindow::onEditText(const QString& text,const QFont& font, const QColor&
         TEXT_TOOL->setText(dialog.text(), dialog.font(), dialog.color(), dialog.antialias(), dialog.position());
 }
 
-/*
-
-    | LAYERS MENU |
-
-*/
-
-void MainWindow::on_actionNew_layer_triggered()
-{
-    m_layerListWidget->addLayer();
-}
-
-void MainWindow::on_actionRemove_layer_triggered()
-{
-    m_layerListWidget->deleteLayer();
-}
-
 /*
 
     | SELECTION MENU |
@@ -1210,7 +1260,7 @@ void MainWindow::on_actionDustReduction_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("dustreduction");
+    applyThreadedFilterMP("dustreduction");
 }
 
 void MainWindow::on_actionDespeckle_triggered()
@@ -1231,21 +1281,21 @@ void MainWindow::on_actionImpulse_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("impulseNoise");
+    applyThreadedFilterMP("impulseNoise");
 }
 
 void MainWindow::on_actionLaplacian_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("laplacianNoise");
+    applyThreadedFilterMP("laplacianNoise");
 }
 
 void MainWindow::on_actionPoisson_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("poissonNoise");
+    applyThreadedFilterMP("poissonNoise");
 }
 
 void MainWindow::on_actionGrayScale_triggered()
@@ -1301,7 +1351,7 @@ void MainWindow::on_actionOil_Paint_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("oil");
+    applyThreadedFilterMP("oil");
 }
 
 void MainWindow::on_actionCharcoal_Drawing_triggered()
@@ -1448,6 +1498,22 @@ void MainWindow::on_actionShow_grid_triggered()
     }
 }
 
+void MainWindow::getPrevZoomFromScale(QString scaletext)
+{
+    int count = this->zoomCombo->count();
+    for(int i=count;i>0;i--)
+    {
+        int a = this->zoomCombo->itemText(i-1).replace("%","").toInt();
+        int b = scaletext.replace("%","").toInt();
+
+        if((a != 0) && a < b)
+        {
+            this->zoomCombo->setCurrentIndex(i);
+            break;
+        }
+    }
+}
+
 void MainWindow::getNextZoomFromScale(QString scaletext)
 {
     int count = this->zoomCombo->count();
@@ -1456,9 +1522,9 @@ void MainWindow::getNextZoomFromScale(QString scaletext)
         int a = this->zoomCombo->itemText(i).replace("%","").toInt();
         int b = scaletext.replace("%","").toInt();
 
-        if(a > b)
+        if((a != 0) && a > b)
         {
-            this->zoomCombo->setCurrentIndex(i-1);
+            this->zoomCombo->setCurrentIndex(i);
             break;
         }
     }
@@ -1470,15 +1536,17 @@ void MainWindow::on_actionZoom_in_triggered()
     {
         getNextZoomFromScale(this->zoomCombo->currentText());
     }
-
-    if(this->zoomCombo->currentIndex()+1 < this->zoomCombo->count() && this->zoomCombo->currentIndex()>0)
+    else
     {
-        this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
-    }
+        if(this->zoomCombo->currentIndex()+1 < this->zoomCombo->count() && this->zoomCombo->currentIndex()>0)
+        {
+            this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
+        }
 
-    if(this->zoomCombo->currentText() == "")
-    {
-        this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
+        if(this->zoomCombo->currentText() == "")
+        {
+            this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
+        }
     }
 
     PaintWidget *widget = getCurrentPaintWidget();
@@ -1490,6 +1558,11 @@ void MainWindow::on_actionZoom_in_triggered()
 
 void MainWindow::on_actionZoom_out_triggered()
 {
+    if(this->zoomCombo->currentIndex()==0)
+    {
+        getPrevZoomFromScale(this->zoomCombo->currentText());
+    }
+
     if(this->zoomCombo->currentIndex()-1 > 1)
     {
         this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()-1);
@@ -1517,16 +1590,6 @@ void MainWindow::on_actionOriginal_size_triggered()
     }
 }
 
-void MainWindow::on_actionAuto_zoom_triggered()
-{
-    PaintWidget *widget = getCurrentPaintWidget();
-    widget->autoScale();
-    connect(widget, &PaintWidget::zoomChanged, [this] (float scale) {
-        this->zoomCombo->setItemText(0, QString::number((int)(scale*100)).append("%"));
-        this->zoomCombo->setCurrentIndex(0);
-    });
-}
-
 void MainWindow::on_actionFull_screen_triggered()
 {
     if(this->isFullScreen())
@@ -1590,11 +1653,11 @@ void MainWindow::batchProcess_batchProgress(int index,int total)
 {
     if(index < total)
     {
-        this->setWindowTitle(QString("PhotoFlare - %1/%2 (%3%)").arg(index).arg(total).arg(int(100 * (float)index/(float)total)));
+        this->setWindowTitle(QString("Photoflare - %1/%2 (%3%)").arg(index).arg(total).arg(int(100 * static_cast<float>(index)/static_cast<float>(total))));
     }
     else
     {
-        this->setWindowTitle(QString("PhotoFlare"));
+        this->setWindowTitle(QString("Photoflare"));
     }
 }
 
@@ -2060,11 +2123,14 @@ void MainWindow::onMultiWindowModeChanged(bool multiWindowMode)
 
 void MainWindow::onSubWindowActivated(QMdiSubWindow *window)
 {
-    Q_UNUSED(window)
+    Q_UNUSED(window);
+    // Set the previously selected tool as active
+    refreshTools();
+
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
     {
-        QString scale = QString::number((int)(widget->getScale()*100)).append("%");
+        QString scale = QString::number(static_cast<int>(widget->getScale()*100)).append("%");
         int index = this->zoomCombo->findText(scale);
         if(index < 0)
         {
@@ -2250,10 +2316,13 @@ void MainWindow::createKeyboardShortcuts()
     ui->actionDuplicate->setShortcut(QString("Ctrl+U"));
     ui->actionImage_Size->setShortcut(QString("Ctrl+H"));
     ui->actionCrop->setShortcut(QString("Ctrl+Shift+H"));
+    // Selection Menu
+    ui->actionSelect_all->setShortcut(QString("Ctrl+A"));
     //View Menu
     ui->actionToolpalette->setShortcut(QString("Ctrl+L"));
     ui->actionZoom_in->setShortcut(QKeySequence::ZoomIn);
     ui->actionZoom_out->setShortcut(QKeySequence::ZoomOut);
+    ui->actionOriginal_size->setShortcut(QString("Ctrl+0"));
     ui->actionFull_screen->setShortcut(QString("Ctrl+F"));
 }
 
@@ -2278,7 +2347,7 @@ void MainWindow::addPaintWidget(PaintWidget *widget)
     widget->autoScale();
 
     connect(widget, &PaintWidget::zoomChanged, [this] (float scale) {
-        this->zoomCombo->setItemText(0, QString::number((int)(scale*100)).append("%"));
+        this->zoomCombo->setItemText(0, QString::number(static_cast<int>(scale*100)).append("%"));
         this->zoomCombo->setCurrentIndex(0);
     });
 
@@ -2338,42 +2407,44 @@ void MainWindow::on_actionContrastplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("contrastplus");
+
+    applyThreadedFilterMP("contrastplus");
+
 }
 
 void MainWindow::on_actionContrastminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("contrastminus");
+    applyThreadedFilterMP("contrastminus");
 }
 
 void MainWindow::on_actionSaturationplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("saturationplus");
+    applyThreadedFilterMP("saturationplus");
 }
 
 void MainWindow::on_actionSaturationminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("saturationminus");
+    applyThreadedFilterMP("saturationminus");
 }
 
 void MainWindow::on_actionGammaCorrectplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("gammacorrectplus");
+    applyThreadedFilterMP("gammacorrectplus");
 }
 
 void MainWindow::on_actionGammaCorrectminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("gammacorrectminus");
+    applyThreadedFilterMP("gammacorrectminus");
 }
 
 void MainWindow::on_actionGradient_triggered()
@@ -2543,8 +2614,6 @@ void MainWindow::disableUnimplementedActions(bool hide)
         ui->actionTransform_2->setVisible(false);
         ui->actionTransparency_mask->setVisible(false);
         ui->actionValidate->setVisible(false);
-        //Hide layers for now
-        ui->menuLayers->menuAction()->setVisible(false);
     }
     else
     {
@@ -2601,7 +2670,5 @@ void MainWindow::disableUnimplementedActions(bool hide)
         ui->actionTransform_2->setEnabled(false);
         ui->actionTransparency_mask->setEnabled(false);
         ui->actionValidate->setEnabled(false);
-        //Hide layers for now
-        ui->menuLayers->setEnabled(false);
     }
 }
