@@ -1,9 +1,25 @@
 /*
+    This file is part of Photoflare.
 
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
+*/
+
+/*
   Filter manager class.
 
   Some of the filters are implemented by ImageMagick through the Magick++ API.
-
+  Others use Qt QGraphics methods.
 */
 
 //#include <QDebug>
@@ -19,6 +35,7 @@
 #include <QGraphicsEffect>
 #include <QGraphicsScene>
 #include <QGraphicsPixmapItem>
+
 //#include <QElapsedTimer>
 
 #include "FilterManager.h"
@@ -303,19 +320,13 @@ QImage FilterManager::reinforce(const QImage &image)
 
 QImage FilterManager::grayscale(const QImage &image)
 {
-    QImage modifiedImage = image.convertToFormat(image.hasAlphaChannel() ?
-    QImage::Format_ARGB32 : QImage::Format_RGB32);
+    Magick::Image *magickImage = d->fromQtImage(image);
+    magickImage->modulate(100,0,0);
 
-     unsigned int *data = (unsigned int*)modifiedImage.bits();
-     int pixelCount = modifiedImage.width() * modifiedImage.height();
+    QImage modifiedImage = d->toQtImage(magickImage);
+    delete magickImage;
 
-     // Convert each pixel to grayscale
-     for(int i = 0; i < pixelCount; ++i) {
-        int val = qGray(*data);
-        *data = qRgba(val, val, val, qAlpha(*data));
-        ++data;
-     }
-     return modifiedImage;
+    return modifiedImage;
 }
 
 QImage FilterManager::oldPhoto(const QImage &image)
@@ -592,28 +603,12 @@ QImage FilterManager::rotateCW(const QImage &image)
 
 QImage FilterManager::setBrightness(const QImage &image, int brightness)
 {
-  //16.04
-  /*
-        Magick::Image *magickImage = d->fromQtImage(image);
-        magickImage->modulate(brightness + 100.0f, 100.0f, 100.0f);
+    Magick::Image *magickImage = d->fromQtImage(image);
+    magickImage->modulate(brightness + 100.0f, 100.0f, 100.0f);
 
-        QImage modifiedImage = d->toQtImage(magickImage);
-        delete magickImage;
+    QImage modifiedImage = d->toQtImage(magickImage);
+    delete magickImage;
 
-        return modifiedImage;
-  */
-  
-    QImage modifiedImage = image;
-
-    for(int i=0; i<modifiedImage.width(); i++)
-    {
-        for(int j=0; j<modifiedImage.height(); j++)
-        {
-            QColor color = modifiedImage.pixelColor(i,j);
-            color.setHsv(color.hue(), color.saturation(), changeBrightness(color.value(),brightness), color.alpha());
-            modifiedImage.setPixelColor(i, j, color);
-        }
-    }
     return modifiedImage;
 }
 
